from datetime import datetime
from fastapi import APIRouter, Depends, status
from sqlalchemy.orm import Session

from app.database import get_db
from app import schemas

router = APIRouter()


@router.get("/", response_model=schemas.HealthCheck)
def health_check(db: Session = Depends(get_db)):
    """
    Health check endpoint
    """
    # Verify database connection is working
    try:
        db.execute("SELECT 1")
        db_status = "healthy"
    except Exception:
        db_status = "unhealthy"
        
    return {
        "status": db_status,
        "timestamp": datetime.now()
    }